@@ -44,7 +44,7 @@ Number of screens available on this display.
 =head2 screen
 
    my $screen= $display->screen();  # alias for $display->default_screen
-   my $screen= $display->screen(3); # or some specific screen
+   my $screen= $display->screen(3); # get some specific screen
 
 Get a L<X11::Xlib::Screen> object, to query per-screen attributes.
 
@@ -65,9 +65,22 @@ sub screen {
     @_ > 1? $_[0]{screens}[$_[1]] : $_[0]{default_screen};
 }
 
-=head2 on_error_cb
+=head2 on_key_event
 
-  $display->on_error_cb(sub {
+  $display->on_key_event(sub {
+    my ($display, $event, $is_press, $character)= @_;
+    ...
+  });
+
+Handler for key events.  Not used until you call L</dispatch_event>.
+
+=head2 on_mouse_event
+
+  $display->on_mouse_event
+
+=head2 on_error
+
+  $display->on_error(sub {
     my ($display, $event)= @_;
     if ($event) {
       # inspect $event (instance of XEvent) and handle/log as appropriate
@@ -227,7 +240,7 @@ Push any queued messages to the X server.
 
 =head3 flush_sync
 
-Push any queued messages to the x server and wait for all replies.
+Push any queued messages to the X server and wait for all replies.
 
 =head3 flush_sync_discard
 
@@ -588,6 +601,41 @@ sub XCreateSimpleWindow {
 
 =head2 INPUT STATE/CONTROL
 
+=head3 keymap
+
+  my $keymap= $display->keymap; # lazy-loaded instance of X11::Xlib::Keymap
+
+X11 Operates on keyboard scan codes, and leaves interpreting them to the
+client.  The server holds a mapping table of scan codes and modifiers which
+all clients share and can modify as needed, though the X server never uses the
+table itself.
+The details are hairy enough that I moved them to their own module.
+See L<X11::Xlib::Keymap> for details.
+
+The first time you access C<keymap> it fetches the tables from the server.
+The tables may change on the fly, so you should watch for MappingNotify events
+to know when to reload the keymap.
+
+Note that if you only need Latin-1 translation of key codes, you can just use
+L<X11::Xlib/XLookupString> and L<X11::Xlib/XRefreshKeyboardMapping> to have
+Xlib do all the heavy lifting.
+
+=cut
+
+sub keymap {
+    my $self= shift;
+    if (@_) { $self->{keymap}= shift; delete $self->{keymap_reverse}; }
+    $self->{keymap} ||= $self->_build_keymap if defined wantarray;
+}
+
+sub _build_keymap {
+    my $self= shift;
+    require X11::Xlib::Keymap;
+    return X11::Xlib::Keymap->new(
+        display => $self,
+    );
+}
+
 =head3 keyboard_leds
 
   my $bits= $display->keyboard_leds;
@@ -610,7 +658,7 @@ when working with XIDs that weren't already wrapped by this module.
 
 =head3 get_cached_xobj
 
-  my $obj= $display->get_cached_xobj( $xid, $class, %new_args );
+  my $obj= $display->get_cached_xobj( $xid, $class, @new_args );
 
 If C<$xid> already references an object, return that object.  Else create
 a new object of type C<$class> and initialize it with the list of arguments.
@@ -632,14 +680,20 @@ sub get_cached_xobj {
 
 =head3 get_cached_colormap
 
+  my $colormap= $display->get_cached_colormap($xid, @new_args);
+
 Shortcut for L</get_cached_xobj> that implies a class of L<X11::Xlib::Colormap>
 
 =head3 get_cached_pixmap
 
+  my $pixmap= $display->get_cached_pixmap($xid, @new_args);
+
 Shortcut for L</get_cached_xobj> that implies a class of L<X11::Xlib::Pixmap>
 
 =head3 get_cached_window
 
+  my $window= $display->get_cached_window($xid, @new_args);
+
 Shortcut for L</get_cached_xobj> that implies a class of L<X11::Xlib::Window>
 
 =cut
